Module blaxel.models.store_agent_labels
=======================================

Classes
-------

`StoreAgentLabels()`
:   Store agent labels
    
    Method generated by attrs for class StoreAgentLabels.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties: dict[str, typing.Any]`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :